@@ -5,7 +5,7 @@ OC.L10N.register(
     "Request unauthorized. Are you logged in?" : "درخواست غیر مجاز. آیا وارد سیستم شده اید؟",
     "Token expired or app not enabled! Reload the page!" : "گفتگوی منقضی شده یا برنامه فعال نشده است! بارگیری مجدد صفحه!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "خطای سرور داخلی! لطفاً برای اطلاعات بیشتر ، پرونده / nextcloud.log خود را بررسی کنید!",
-    "Request failed, Nextcloud is in currently in maintenance mode!" : "درخواست انجام نشد ، Nextcloud در حال حاضر در حالت تعمیر و نگهداری است!",
+    "Request failed, Nextcloud is in currently in maintenance mode!" : "درخواست انجام نشد، نکست‌کلود در حال حاضر در حالت تعمیر و نگهداری است!",
     "Unread articles" : "مطالب خوانده نشده",
     "News" : "اخبار",
     "An RSS/Atom feed reader" : "An RSS/Atom feed reader",
